#
# spec file for package libgpg-error
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgpg-error
Version:        1.51
Release:        1.1
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gnupg.org/software/libgpg-error/
Source0:        https://gnupg.org/ftp/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2
Source1:        https://gnupg.org/ftp/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2.sig
# http://www.gnupg.org/signature_key.en.html
Source2:        https://gnupg.org/signature_key.asc#/%{name}.keyring
Source3:        baselibs.conf
#PATCH-FIX-OPENSUSE Do not pull revision info from GIT when autoconf is run
Patch0:         libgpg-error-nobetasuffix.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package -n libgpg-error0
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Provides:       libgpg-error = %{version}
Obsoletes:      libgpg-error < %{version}

%description -n libgpg-error0
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package devel
Summary:        Development package for libgpg-error
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND MIT
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgpg-error0 = %{version}
Requires(post): info
Requires(preun): info

%description devel
Files needed for software development using libgpg-error.

%prep
%autosetup -p1

autoreconf -fiv

%build
%configure --disable-static \
	   --enable-install-gpg-error-config
%make_build

%install
%make_install
rm %{buildroot}%{_libdir}/libgpg-error.la
# Drop the lisp stuff, it depends on ASDF and CFFI
# which needs to be packaged first
rm -r %{buildroot}%{_datadir}/common-lisp
%find_lang %{name}

%check
%make_build check

%post -n libgpg-error0 -p /sbin/ldconfig
%postun -n libgpg-error0 -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/gpgrt.info.gz

%preun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gpgrt.info.gz

%files -n libgpg-error0 -f %{name}.lang
%license COPYING.LIB COPYING
%doc README NEWS ChangeLog AUTHORS ABOUT-NLS
%{_libdir}/libgpg-error*.so.*

%files devel
%{_bindir}/*
%{_libdir}/libgpg-error*.so
%{_libdir}/pkgconfig/gpg-error.pc
%{_includedir}/*
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/gpg-error.m4
%{_datadir}/aclocal/gpgrt.m4
%dir %{_datadir}/libgpg-error
%{_datadir}/libgpg-error/errorref.txt
%{_infodir}/gpgrt.info%{?ext_info}
%{_mandir}/man1/gpg-error-config.*
%{_mandir}/man1/gpgrt-config.*

%changelog
* Wed Nov 13 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.51:
  * Add GPGRT_PROCESS_ALLOW_SET_FG for gpgrt_process_spawn. [rEb79d4206f4]
  * Add new spawn function to modify the environment. [T7307]
  * Fix missing environ var for macOS and others. [T7169,T7307]
  * Fix forgotten _gpgrt_post_syscall on create pipe failure. [rEbcab96484d]
  * Let gpgrt_poll return an error for a closed fd. [rE4a3dc85f69]
  * Fix build error introduced by C-committee stupidity. [T7344]
  * Interface changes relative to the 1.50 release:
  - _gpg_w32_gettext_use_utf8           EXTN (new value 2).
  - gpgrt_spawn_actions_set_env_rev     NEW.
  - GPGRT_PROCESS_ALLOW_SET_FG          NEW.
  * Release-info: https://dev.gnupg.org/T7164
  * Rebase libgpg-error-nobetasuffix.patch
* Thu Jun 20 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.50:
  * New set of process spawn functions. [T6249]
  * Fixed return type for gpgrt_b64dec_proc and gpgrt_b64dec_finish
    to gpg_err_code_t.  This enum return type is in almost all cases
    compatible to the formerly used gpg_error_t (i.e. unsigned int).
  * Interface changes relative to the 1.49 release:
    gpgrt_process_t                     CHANGED (never used).
    gpgrt_spawn_actions_t               NEW type.
    gpgrt_process_requests              NEW enum.
    gpgrt_process_spawn                 NEW.
    gpgrt_process_terminate             NEW.
    gpgrt_process_get_streams           NEW.
    gpgrt_process_ctl                   NEW.
    gpgrt_process_wait                  NEW.
    gpgrt_process_release               NEW.
    gpgrt_spawn_actions_new             NEW.
    gpgrt_spawn_actions_release         NEW.
    gpgrt_spawn_actions_set_redirect    NEW.
    gpgrt_spawn_actions_set_environ     NEW (posix only).
    gpgrt_spawn_actions_set_inherit_fds NEW (posix only).
    gpgrt_spawn_actions_set_atfork      NEW (posix only).
    gpgrt_spawn_actions_set_envvars     NEW (w32 only).
    gpgrt_spawn_actions_set_inherit_handles NEW (w32 only).
    GPGRT_PROCESS_DETACHED              NEW.
    GPGRT_PROCESS_NO_CONSOLE            NEW.
    GPGRT_PROCESS_NO_EUID_CHECK         NEW.
    GPGRT_PROCESS_STDIN_PIPE            NEW.
    GPGRT_PROCESS_STDOUT_PIPE           NEW.
    GPGRT_PROCESS_STDERR_PIPE           NEW.
    GPGRT_PROCESS_STDINOUT_SOCKETPAIR   NEW.
    GPGRT_PROCESS_STDIN_KEEP            NEW.
    GPGRT_PROCESS_STDOUT_KEEP           NEW.
    GPGRT_PROCESS_STDERR_KEEP           NEW.
    GPGRT_PROCESS_STDFDS_SETTING        NEW.
    GPGRT_SPAWN_INHERIT_FILE            REMOVED (never used).
    GPGRT_SPAWN_NONBLOCK                REMOVED (never used).
    GPGRT_SPAWN_RUN_ASFW                REMOVED (never used).
    GPGRT_SPAWN_DETACHED                REMOVED (never used).
    GPGRT_SPAWN_KEEP_STDIN              REMOVED (never used).
    GPGRT_SPAWN_KEEP_STDOUT             REMOVED (never used).
    GPGRT_SPAWN_KEEP_STDERR             REMOVED (never used).
  * Release-info: https://dev.gnupg.org/T7102
* Mon Apr 29 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.49:
  * Two new functions to improve the logging interface. The
    gpgrt_logv_domain is currently the same as gpgrt_logv_prefix but
    allows to pass a domain string so that in future we will be able to
    select log output by domain. It also provide a non yet functional
    feature to include a hex dump.
  * Add a "trunc" keyword to gpgrt_log_printhex. [rE0a39fbefcb]
  * Avoid an endless loop in the argparser due to a conf file read
    error. [rE2dc93cfecc]
  * Interface changes relative to the 1.48 release:
  - gpgrt_add_post_log_func        NEW.
  - gpgrt_logv_domain              NEW.
  * Release-info: https://dev.gnupg.org/T7012
* Mon Feb 26 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.48:
  * New configure option --with-libtool-modification.  [T6619]
  * New option parser flag to detect commands given without a double
    dash.  There is also the new meta command "command-mode" to set
    this flag via a config file.  [T6978]
  * Added an es_fopen mode flag "sequential" with support on Windows.
    [rE7a42ff0ec9]
  * Added an es_fopen mode flag "wipe" to cleanup internal buffers at
    close time.  [T6954]
  * New function gpgrt_wipememory.  [T6964]
  * Improvements to setenv on Windows.  [rE89e53ad90f]
  * Fixed call to estream-printf string filters.  [T6737]
  * Many improvements to the yat2m tool.
  * Updates to the build system.
  * Interface changes relative to the 1.47 release:
  - ARGPARSE_FLAG_COMMAND          NEW.
  - gpgrt_wipememory               NEW.
  * Release-info: https://dev.gnupg.org/T6441
  * Update upstream libgpg-error.keyring
* Tue Oct 17 2023 Pedro Monreal <pmonreal@suse.com>
- Do not pull revision info from GIT when autoconf is run. This
  removes the -unknown suffix after the version number.
  * Add libgpg-error-nobetasuffix.patch [bsc#1216334]
* Wed Apr 12 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 1.47:
  * New error codes for PUKs and reset codes. [T6421]
  * Avoid segv in logging with improper use of the "socket://".
  * Fixed translation of argparse's internal option --help.
  * Interface changes relative to the 1.46 release:
  - GPG_ERR_SOURCE_TKD             NEW.
  - GPG_ERR_BAD_PUK                NEW.
  - GPG_ERR_NO_RESET_CODE          NEW.
  - GPG_ERR_BAD_RESET_CODE         NEW.
  - GPGRT_SPAWN_KEEP_STDIN         NEW.
  - GPGRT_SPAWN_KEEP_STDOUT        NEW.
  - GPGRT_SPAWN_KEEP_STDERR        NEW.
  - GPGRT_SPAWN_INHERIT_FILE       NEW.
  * Release-info: https://dev.gnupg.org/T6231
* Mon Oct 17 2022 Pedro Monreal <pmonreal@suse.com>
- Update to 1.46:
  * Support for bidirectional pipes under Windows.
  * REG_DWORD types are now support in the Windows Registry.
  * Added ES_SYSHD_SOCK support for gpgrt_sysopen under Windows.
  * Fixed gpgrt_log_get_fd for the file case.
  * Avoids header problem with C11 and "noreturn".
  * The gpg-error-config command is not installed by default, because
    it is now replaced by use of pkg-config/gpgrt-config with
    gpg-error.pc.  Supply --enable-install-gpg-error-config configure
    option, if it's really needed.
  * Fixed support of posix-lock for FreeBSD.
  * Build fixes for some Mingw tool chain versions.
  * Removed remaining support for WindowsCE.
  * Updated config.guess, config.sub, and config.rpath.
  * gpg-error-config is now only installed when enabled.
  * System paths are now stripped from --cflags --and --libs.
* Thu Apr  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.45:
  * gpgrt_access and gpgrt_mkdir now support file names longer than
    MAX_PATH
* Wed Feb  2 2022 Pedro Monreal <pmonreal@suse.com>
- Update to 1.44:
  * Fix dependency to gpg-error-config-test.sh.
  * Run the posix locking test only on supported platforms.
  * Detect Linux systems using musl.
  * Fix gpg-error-config-test for PKG_CONFIG_LIBDIR.
  * Fix returning of option attributes for options with args.
  * Add Turkish translations.
* Fri Nov  5 2021 Pedro Monreal <pmonreal@suse.com>
- Update to 1.43:
  * Fix for building against GNU libc 2.34.
  * Fix gpgrt-config problems.
  * Fix gpgrt_free for legacy platforms.
  * Fix truncation of error message in the middle of a character.
  * Fix the --disable-threads configure options.
  * Improve lock-obj generation for cross-builds.
  * Improve cross-builds.
  * Improve gpgrt_wait_processes.
* Fri Jun 18 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static).
* Fri Mar 26 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.42:
  * Improve cross-compiling support
  * Improve $libdir determination by gpgrt-config
  * Support --disable-thread by gen-lock-obj.sh
  * Interface changes relative to the 1.40 release
    GPG_ERR_SOURCE_TPM2D
* Mon Jan 25 2021 Dirk Müller <dmueller@suse.com>
- update to 1.41:
  * Fixes another glitch in the "ignore" meta command.
  * Fixes two typos in the German translation.
  * New function gpgrt_access.
  * Make "ignore" meta command work correctly in the option parser.
  * Interface changes relative to the 1.39 release:
  gpgrt_access                     NEW.
* Wed Sep  2 2020 Pedro Monreal Gonzalez <pmonreal@suse.com>
- Update to 1.39:
  * "gpg-error --lib-version" works again.
  * New function gpgrt_fcancel as alternative to gpgrt_close. This
    function avoid flushing out buffered data and also tries to delete
    a newly created file.
  * Update the gnupg project keyring
  * Interface changes relative to the 1.38 release:
  - gpgrt_fcancel: NEW.
* Sun May 31 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.38:
  * New option parser features to implement system wide
    configuration files
  * New functions to build file names
  * New function to help reallocating arrays
  * Protect gpgrt_inc_errorcount against counter overflow
- drop needless autotools build dependencies that were added for
  gawk5.patch
* Mon Feb 17 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to 1.37
  Release-info: https://dev.gnupg.org/T4772
  * Fixes a build problems when using Gawk 5.0  [#4459]
  * Improves cross-compiling support.  [#4643]
  * New error codes to map SQLite primary error codes.
  * Now uses poll(2) instead of select(2) in gpgrt_poll if possible.
  * Fixes a bug in gpgrt_close.  [#4698]
  * Fixes a few minor portability bugs.
  * New interfaces in this release:
    GPG_ERR_NO_KEYBOXD    GPG_ERR_KEYBOXD       GPG_ERR_NO_SERVICE
    GPG_ERR_SERVICE       GPG_ERR_SQL_OK        GPG_ERR_SQL_ERROR
    GPG_ERR_SQL_INTERNAL  GPG_ERR_SQL_PERM      GPG_ERR_SQL_ABORT
    GPG_ERR_SQL_BUSY      GPG_ERR_SQL_LOCKED    GPG_ERR_SQL_NOMEM
    GPG_ERR_SQL_READONLY  GPG_ERR_SQL_INTERRUPT GPG_ERR_SQL_IOERR
    GPG_ERR_SQL_CORRUPT   GPG_ERR_SQL_NOTFOUND  GPG_ERR_SQL_FULL
    GPG_ERR_SQL_CANTOPEN  GPG_ERR_SQL_PROTOCOL  GPG_ERR_SQL_EMPTY
    GPG_ERR_SQL_SCHEMA    GPG_ERR_SQL_TOOBIG    GPG_ERR_SQL_CONSTRAINT
    GPG_ERR_SQL_MISMATCH  GPG_ERR_SQL_MISUSE    GPG_ERR_SQL_NOLFS
    GPG_ERR_SQL_AUTH      GPG_ERR_SQL_FORMAT    GPG_ERR_SQL_RANGE
    GPG_ERR_SQL_NOTADB    GPG_ERR_SQL_NOTICE    GPG_ERR_SQL_WARNING
    GPG_ERR_SQL_ROW       GPG_ERR_SQL_DONE
- Remove patch fixed upstream.
  * gawk5.patch
* Fri Aug 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix buidling with gawk 5.0 and newer:
  * gawk5.patch
* Tue Mar 19 2019 Karol Babioch <kbabioch@suse.de>
- Update to 1.36:
  * Two new error codes to better support PIV cards
  * Support armv7a-unknown-linux-gnueabihf
* Mon Jan 28 2019 Karol Babioch <kbabioch@suse.de>
- Update to 1.35:
  * Distribute the correct gpgrt-config
* Wed Jan 16 2019 Karol Babioch <kbabioch@suse.de>
- update to 1.34:
  * Support for riscv32
  * New API to allow emergency cleanup after internal fatal errors
  * Minor bug and portability fixes
* Sat Dec  8 2018 astieger@suse.com
- update to 1.33:
  * New unified config script gpgrt-config
  * The log functions now sanitize strings printed with the "%%s"
    format specifier
  * New fprintf style function to apply a custom filter for string
    arguments
  * New function to compare version strings
* Thu Jul 12 2018 kbabioch@suse.com
- Update to 1.32:
  * Fixes a problem with gpgrt_fflush and gpgrt_fopencookie
  * Fixes a problem with the C11 header stdnoreturn.h
* Sat May 12 2018 antoine.belvire@opensuse.org
- Fix %%install_info_delete usage:
  * It has to be performed in %%preun not in %%postun.
  * See https://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25install_info_delete.
* Wed May  2 2018 astieger@suse.com
- update to 1.31:
  * Fixes for platforms other than GNU/Linux
  * New translation for Spanish
* Mon Apr 30 2018 astieger@suse.com
- update to 1.30:
  * fixes for platforms other than GNU/Linux
  * Use %%license (boo#1082318)
* Thu Apr 19 2018 astieger@suse.com
- update signature files as more signatures got added
- refresh package signing keyring from upstream
* Wed Apr 11 2018 kbabioch@suse.com
- Cleaned up spec file with spec-cleaner
* Wed Apr 11 2018 kbabioch@suse.com
- Update to 1.29:
  * The yat2m tool is during cross-compile now also installed on the
  host platform.
  * New option parser and associated functions similar to the one used
  by GnuPG.
  * New Base-64 encoder.
  * Fixes regression in 1.28 for arm64 and w64 builds.
- Dropped fix_aarch64.patch (included upstream now)
* Thu Mar 22 2018 guillaume.gardet@opensuse.org
- Backport upstream patch to fix AArch64 build:
  * fix_aarch64.patch
* Tue Mar 13 2018 kbabioch@suse.com
- update to 1.28:
  * The formerly internal yat2m tool is now installed for a native build.
  * The new files gpgrt.m4 and gpgrt-config are now installed. They can
    be used instead of gpg-error.m4 and gpg-error-config.
  * New logging functions similar to those used by GnuPG.
  * New helper functions for platform abstraction.
  * Interface changes
* Tue Mar  7 2017 astieger@suse.com
- update to 1.27:
  * Added a Base64 decoder.
  * Added support for the sh3 architecture.
  * Added header gpgrt.h as an alias for gpg-error.h.
  * Fixed macro GPGRT_GCC_VERSION.
  * Interface changes relative to the 1.26 release:
  gpgrt_b64state_t                 NEW type.
  gpgrt_b64dec_start               NEW.
  gpgrt_b64dec_proc                NEW.
  gpgrt_b64dec_finish              NEW.
  GPG_ERR_WRONG_NAME               NEW.
  gpgrt.h                          NEW header.
* Thu Dec 22 2016 astieger@suse.com
- update to 1.26:
  * New option --desc for gpg-error.
  * Interface changes relative to the 1.25 release:
  GPG_ERR_UNKNOWN_FLAG         NEW.
  GPG_ERR_INV_ORDER            NEW.
  GPG_ERR_ALREADY_FETCHED      NEW.
  GPG_ERR_TRY_LATER            NEW.
  GPG_ERR_SYSTEM_BUG           NEW.
  GPG_ERR_DNS_UNKNOWN          NEW.
  GPG_ERR_DNS_SECTION          NEW.
  GPG_ERR_DNS_ADDRESS          NEW.
  GPG_ERR_DNS_NO_QUERY         NEW.
  GPG_ERR_DNS_NO_ANSWER        NEW.
  GPG_ERR_DNS_CLOSED           NEW.
  GPG_ERR_DNS_VERIFY           NEW.
  GPG_ERR_DNS_TIMEOUT          NEW.
* Tue Nov 15 2016 astieger@suse.com
- update to 1.25:
  * New interface gpgrt_get_syscall_clamp to allow libaries to make
    use of Libgpg-error's system call wrapper functions.
  * Fixed bug in the locking code when used with the nPth threading
    library.
  * Added new error codes.
  * Interface changes relative to the 1.23 release:
    gpgrt_get_syscall_clamp          NEW.
    GPG_ERR_ENGINE_TOO_OLD	     NEW.
    GPG_ERR_WINDOW_TOO_SMALL         NEW.
    GPG_ERR_WINDOW_TOO_LARGE         NEW.
    GPG_ERR_MISSING_ENVVAR	     NEW.
    GPG_ERR_USER_ID_EXISTS           NEW.
    GPG_ERR_NAME_EXISTS              NEW.
    GPG_ERR_DUP_NAME                 NEW.
    GPG_ERR_TOO_OLD                  NEW.
    GPG_ERR_TOO_YOUNG                NEW.
* Mon Jul 18 2016 astieger@suse.com
- update to 1.24:
  * Fixes a bug in es_fclose_snatch when used used after es_fseek.
  * Fixes building without thread support.
  * New configure option --disable-tests.
* Wed Jun 15 2016 astieger@suse.com
- update to 1.23:
  * Fixes an assertion failure due to es_flush on read/write streams.
  * Fixes a bug with a too short memory limit is es_fopenmen.
  * Interface changes relative to the 1.22 release:
    GPG_ERR_SUBKEYS_EXP_OR_REV       NEW.
* Fri Apr 29 2016 astieger@suse.com
- update to 1.22:
  * Support for LeakSanitizer with the gpgrt_annotate_leaked_object
    inline function.
  * Interface changes relative to the 1.21 release:
    GPG_ERR_DB_CORRUPTED             NEW.
    gpgrt_annotate_leaked_object     NEW inline func.
    GPGRT_ENABLE_W32_ICONV_MACROS    NEW.
    gpgrt_w32_iconv_open             NEW.
    gpgrt_w32_iconv_close            NEW.
    gpgrt_w32_iconv                  NEW.
* Mon Dec 14 2015 astieger@suse.com
- update to 1.21:
  * New functions gpgrt_poll and gpgrt_set_nonblock.  For now only
    pipes and sockets on Unix are supported.
  * Interface changes relative to the 1.20 release:
    gpgrt_set_nonblock               NEW.
    gpgrt_get_nonblock               NEW.
    gpgrt_poll                       NEW.
    gpgrt_poll_t                     NEW type.
    es_poll_t                        NEW type.
    es_set_nonblock                  NEW macro.
    es_get_nonblock                  NEW macro.
    es_poll                          NEW macro.
    GPG_ERR_TRUE                     NEW.
    GPG_ERR_FALSE                    NEW.
    GPG_ERR_NO_NAME                  NEW.
    GPG_ERR_NO_KEY                   NEW.
    GPG_ERR_SERVER_FAILED            NEW.
* Wed Aug 26 2015 astieger@suse.com
- update to 1.20:
  * New macros for GCC attributes.
  * Allow building without thread support.
  * Build without a build timestamp by default.
  * Interface changes relative to the 1.19 release:
  GPGRT_VERSION                    NEW macro.
  GPGRT_VERSION_NUMBER             NEW macro.
  GPGRT_INLINE                     NEW macro.
  GPGRT_GCC_VERSION                NEW macro.
  GPGRT_ATTR_NORETURN              NEW macro.
  GPGRT_ATTR_PRINTF                NEW macro.
  GPGRT_ATTR_NR_PRINTF             NEW macro.
  GPGRT_ATTR_FORMAT_ARG            NEW macro.
  GPGRT_ATTR_SENTINEL              NEW macro.
  GPGRT_ATTR_USED                  NEW macro.
  GPGRT_ATTR_UNUSED                NEW macro.
  GPGRT_ATTR_DEPRECATED            NEW macro.
  GPGRT_ATTR_PURE                  NEW macro.
  GPGRT_ATTR_MALLOC                NEW macro.
  GPGRT_HAVE_MACRO_FUNCTION        NEW macro.
  GPGRT_HAVE_PRAGMA_GCC_PUSH       NEW macro.
* Fri Apr 10 2015 astieger@suse.com
- update to 1.19:
  * New set of error codes for use with LDAP.
  * New options --help and --defines for gpg-error.
  * Allow building with gcc 5.
  (replacing patch libgpg-error-1.18-gcc5.patch now removed)
  * Interface changes relative to the 1.18 release:
  GPG_ERR_LDAP_*                   NEW.
* Thu Mar 19 2015 astieger@suse.com
- remove libtool requirement
* Thu Feb 19 2015 rguenther@suse.com
- Add libgpg-error-1.18-gcc5.patch to pass -P to the preprocessor
  when generating files to deal with C preprocessor changes in GCC 4.9 and up.
* Mon Jan 26 2015 andreas.stieger@gmx.de
- update to 1.18:
  * New translations for Hungarian, Portuguese, Russian, and
  traditional Chinese.  Updated other translations.
  * New error codes.
  * Interface changes relative to the 1.17 release:
  GPG_ERR_FORBIDDEN                NEW.
  GPG_ERR_OBJ_TERM_STATE           NEW.
  GPG_ERR_REQUEST_TOO_SHORT        NEW.
  GPG_ERR_REQUEST_TOO_LONG         NEW.
  GPG_ERR_LEGACY_KEY               NEW.
* Wed Oct 15 2014 andreas.stieger@gmx.de
- update to 1.17:
  * New error codes for TLS protocol libraries.
  * New configure option --enable-build-timestamp.
  * New man page for gpg-error-config.
  * Interface changes relative to the 1.16 release:
  GPG_ERR_SOURCE_TLS               NEW.
  GPG_ERR_NO_CERT_CHAIN            NEW.
  GPG_ERR_CERT_TOO_LARGE	          NEW.
  GPG_ERR_INV_RECORD               NEW.
  GPG_ERR_BAD_MAC	          NEW.
  GPG_ERR_UNEXPECTED_MSG           NEW.
  GPG_ERR_COMPR_FAILED             NEW.
  GPG_ERR_WOULD_WRAP               NEW.
  GPG_ERR_FATAL_ALERT              NEW.
  GPG_ERR_NO_CIPHER                NEW.
  GPG_ERR_MISSING_CLIENT_CERT      NEW.
  GPG_ERR_CLOSE_NOTIFY             NEW.
  GPG_ERR_TICKET_EXPIRED           NEW.
  GPG_ERR_BAD_TICKET               NEW.
  GPG_ERR_UNKNOWN_IDENTITY         NEW.
  GPG_ERR_BAD_HS_CERT              NEW.
  GPG_ERR_BAD_HS_CERT_REQ          NEW.
  GPG_ERR_BAD_HS_CERT_VER          NEW.
  GPG_ERR_BAD_HS_CHANGE_CIPHER     NEW.
  GPG_ERR_BAD_HS_CLIENT_HELLO      NEW.
  GPG_ERR_BAD_HS_SERVER_HELLO      NEW.
  GPG_ERR_BAD_HS_SERVER_HELLO_DONE NEW.
  GPG_ERR_BAD_HS_FINISHED          NEW.
  GPG_ERR_BAD_HS_SERVER_KEX        NEW.
  GPG_ERR_BAD_HS_CLIENT_KEX        NEW.
  GPG_ERR_BOGUS_STRING             NEW.
  gpgrt_pending                    NEW.
  gpgrt_pending_unlocked           NEW.
- Build with --enable-build-timestamp=no to prevent unneccessary
  rebuilds of dependent packages
- add required spec for introducted info page
* Sun Sep 21 2014 andreas.stieger@gmx.de
- update to 1.16:
  * Fixed a prototype mismatch.
  * Fix es_fclose for streams opened with "samethread".
* Sat Sep 13 2014 meissner@suse.com
- update to 1.15:
  * This releases fixes problems with the use of off_t and ssize_t by
  the estream functions introduced with 1.14.  Although this is
  technically an ABI break on some platforms, we take this as a
  simple bug fix for 1.14.  The new functions are very unlikely in
  use by any code and thus no breakage should happen.  The 1.14
  tarball will be removed from the archive.
  * Add type gpgrt_off_t which is guaranteed to be 64 bit.
  * Add type gpgrt_ssize_t to make use on Windows easier.  On Unix
  platforms this is an alias for ssize_t.
* Wed Sep 10 2014 andreas.stieger@gmx.de
- update to 1.14:
  * Added gpgrt_lock_trylock.
  * Added the estream library under the name gpgrt and a set of macros
  to use them with their "es_" names.
  * Interface changes relative to the 1.13 release:
  GPG_ERR_KEY_DISABLED         NEW.
  gpgrt_*, GPGPT_*             NEW.
* Sun Apr 27 2014 andreas.stieger@gmx.de
- update to 1.13:
  * Added a portable mutex API.
  * The AM_PATH_GPG_ERROR macro now defines GPG_ERROR_MT_CFLAGS
    and GPG_ERROR_MT_LIBS autoconf output variables for use by
    programs which need gpgrt based thread support.
    gpg-error-config has a new option --mt.
- Interface changes relative to the 1.12 release:
  GPG_ERR_KEY_ON_CARD          NEW.
  GPG_ERR_MAC_ALGO             NEW.
  GPG_ERR_INV_LOCK_OBJ         NEW.
  gpgrt_lock_t                 NEW.
  GPGRT_LOCK_INITIALIZER       NEW.
  GPGRT_LOCK_DEFINE            NEW.
  gpgrt_lock_init              NEW.
  gpgrt_lock_lock              NEW.
  gpgrt_lock_unlock            NEW.
  gpgrt_lock_destroy           NEW.
  gpgrt_yield                  NEW.
- run available tests
- fix SLE 11 SP2 build (make install)
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 1.12
  * Interface changes relative to the 1.11 release:
  GPG_ERR_NO_CRYPT_CTX         NEW.
  GPG_ERR_WRONG_CRYPT_CTX      NEW.
  GPG_ERR_BAD_CRYPT_CTX        NEW.
  GPG_ERR_CRYPT_CTX_CONFLICT   NEW.
  GPG_ERR_BROKEN_PUBKEY        NEW.
  GPG_ERR_BROKEN_SECKEY        NEW.
- drop unused libgpg-error-nld-build.diff
- drop autoreconv call
* Tue Jun 18 2013 coolo@suse.com
- remove gpg verification from bootstrap packages
* Mon Feb 25 2013 andreas.stieger@gmx.de
- update to 1.11
  * New error source GPG_ERR_SOURCE_ASSUAN for Libassuan related
  errors.
  * New macros GPG_ERROR_VERSION and GPG_ERROR_VERSION_NUMBER.  New
  function gpg_error_check_version.
  * Interface changes relative to the 1.10 release:
  GPG_ERR_NO_KEYSERVER          NEW.
  GPG_ERR_INV_CURVE             NEW.
  GPG_ERR_UNKNOWN_CURVE         NEW.
  GPG_ERR_DUP_KEY               NEW.
  GPG_ERR_AMBIGUOUS             NEW.
  GPG_ERR_SOURCE_ASSUAN         NEW.
  gpg_error_check_version       NEW.
  GPG_ERROR_VERSION             NEW.
  GPG_ERROR_VERSION_NUMBER      NEW.
- add offline verification of source signature
* Sat Feb  2 2013 coolo@suse.com
- update license to new format
* Sun Feb 12 2012 crrodriguez@opensuse.org
- Move libraries back to %%{_libdir}, /usr merge project
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct  2 2011 crrodriguez@opensuse.org
-  Update to version 1.10
  * Define GPG_ERR_ENABLE_ERRNO_MACROS.
  * Add GPG_ERR_NOT_INITIALIZED.
  * Add GPG_ERR_MISSING_ISSUER_CERT
* Fri Dec  3 2010 puzel@novell.com
- update to version 1.9
  * New function gpg_err_deinit.
  * Interface changes relative to the 1.8 release:
  GPG_ERR_MISSING_KEY           NEW
  GPG_ERR_TOO_MANY              NEW
  GPG_ERR_LIMIT_REACHED         NEW
  gpg_err_deinit                NEW
- clean up specfile
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Aug 17 2010 puzel@novell.com
- update to version 1.8
  * New option --list for gpg-error.
  * Interface changes relative to the 1.7 release:
  GPG_ERR_NOT_ENABLED           NEW
  GPG_ERR_SOURCE_G13            NEW
  GPG_ERR_NO_ENGINE             NEW
  gpg_err_set_errno             NEW
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Jun  1 2009 puzel@suse.cz
- update to version 1.7
  * Minor fixes and a few new error codes.
  * Interface changes relative to the 1.6 release:
  GPG_ERR_NOT_OPERATIONAL       NEW
  GPG_ERR_NO_PASSPHRASE         NEW
  GPG_ERR_NO_PIN                NEW
* Fri Feb 20 2009 crrodriguez@suse.de
- remove static libraries, there is no reason to use them as
  shared libraries live in /%%{_lib}
* Thu Jan 29 2009 olh@suse.de
- obsolete libgpg-error-XXbit in the library subpackage
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Nov 21 2007 mkoenig@suse.de
- update to version 1.6
  * Minor build system fixes
  * gpg-error has a new option --version
  * Interface changes relative to the 1.4 release:
    GPG_ERR_UNFINISHED            NEW
    GPG_ERR_SOURCE_GPA            NEW
    GPG_ERR_SOURCE_KLEO           NEW
- package branch to conform shlib policy:
  libgpg-error0
* Wed Dec 13 2006 mkoenig@suse.de
- get rid of .la file and fix devel so link
* Tue Dec  5 2006 mkoenig@suse.de
- move shared lib to /%%_lib
* Tue Sep 19 2006 mkoenig@suse.de
- update to version 1.4:
  * New error codes for the Assuan IPC library.
  * New error code GPG_ERR_MISSING_ERRNO
  * New error source GPG_ERR_SOURCE_ANY
  * New convenience functions gpg_err_code_from_syserror and
  gpg_error_from_syserror
* Thu Jul 13 2006 mskibbe@suse.de
- add autoreconf --force ( includes the missing -fPIC option while
  build )
* Wed Jul 12 2006 mskibbe@suse.de
- update to version 1.3 which
  o includes fixes in Makefiles
  o fix cast problems
  o include utf8 functions
  o add some languages
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jun 23 2005 hvogel@suse.de
- require libgpg-error
- add %%clean section
* Thu Oct 14 2004 hvogel@suse.de
- update to version 1.0
* Mon Sep 27 2004 hvogel@suse.de
- fixed ac-quotation of gpg-error.m4
* Mon Jul 19 2004 hvogel@suse.de
- correct nld_build if statement
* Wed Jul 14 2004 adrian@suse.de
- create -devel subpackage
- prepare for NLD
* Mon May 24 2004 ro@suse.de
- added return value to non-void function (main)
* Wed May 19 2004 hvogel@suse.de
- update to version 0.7
* Tue Feb 17 2004 hvogel@suse.de
- initial package, version 0.6
